@@ -6,12 +6,6 @@ import pytd
 import requests
 import json
 
-##-- Declare _env Variables from YML file
-apikey = os.environ['TD_API_KEY'] 
-tdserver = os.environ['TD_API_SERVER']
-sink_database = os.environ['SINK_DB']
-output_table = os.environ['OUTPUT_TABLE']
-
 ### --Function to create datamodel via API below
 def create_model():
 
